==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/StorageGateway/DescribeCachediSCSIVolumes.pm <==

package Paws::StorageGateway::DescribeCachediSCSIVolumes;
  use Moose;
  has VolumeARNs => (is => 'ro', isa => 'ArrayRef[Str]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeCachediSCSIVolumes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StorageGateway::DescribeCachediSCSIVolumesOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::DescribeCachediSCSIVolumes - Arguments for method DescribeCachediSCSIVolumes on Paws::StorageGateway

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeCachediSCSIVolumes on the 
AWS Storage Gateway service. Use the attributes of this class
as arguments to method DescribeCachediSCSIVolumes.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DescribeCachediSCSIVolumes.

As an example:

  $service_obj->DescribeCachediSCSIVolumes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> VolumeARNs => ArrayRef[Str]

  



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeCachediSCSIVolumes in L<Paws::StorageGateway>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.18.tar.gz: Paws-0.18/lib/Paws/StorageGateway/DescribeCachediSCSIVolumes.pm <==

package Paws::StorageGateway::DescribeCachediSCSIVolumes;
  use Moose;
  has VolumeARNs => (is => 'ro', isa => 'ArrayRef[Str]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeCachediSCSIVolumes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StorageGateway::DescribeCachediSCSIVolumesOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::DescribeCachediSCSIVolumes - Arguments for method DescribeCachediSCSIVolumes on Paws::StorageGateway

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeCachediSCSIVolumes on the 
AWS Storage Gateway service. Use the attributes of this class
as arguments to method DescribeCachediSCSIVolumes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeCachediSCSIVolumes.

As an example:

  $service_obj->DescribeCachediSCSIVolumes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> VolumeARNs => ArrayRef[Str]

  



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeCachediSCSIVolumes in L<Paws::StorageGateway>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
